<!-- # ZnDraw Help -->

- **play / pause**: `keypress space`
- **frame forwards / backwards**: `keypress ▶\◀`
- **jump forwards / backwards**: `keypress ▲\▼`
- **center camera around selected particle**: `keypress C`
- **select multiple particles**: `keydown shift`
- **show particle index**: `keydown I`
- **toggle canvas movement**: `keypress F`
- **duplicate selected anchor point**: `keypress D`
- **switch transform control mode**: `keypress T`
- **select / scale drawing geometry**: `keypress shift + mousewheel`
- **add bookmark at current step**: `keypress B`
- **jump between bookmarks**: `shift + keypress ▶\◀`
- **remove bookmark**: `shift + mouse click`
- **toggle drawing mode**: `keypress X`
